declare module "windows.applicationmodel.contacts" {
  export class Rect {
    constructor();
  }

  export enum ContactFieldType {
    email,
    phoneNumber,
    location,
    instantMessage,
    custom,
    connectedServiceAccount,
    importantDate,
    address,
    significantOther,
    notes,
    website,
    jobInfo,
  }

  export enum ContactFieldCategory {
    none,
    home,
    work,
    mobile,
    other,
  }

  export enum ContactSelectionMode {
    contacts,
    fields,
  }

  export enum ContactEmailKind {
    personal,
    work,
    other,
  }

  export enum ContactPhoneKind {
    home,
    mobile,
    work,
    other,
  }

  export enum ContactAddressKind {
    home,
    work,
    other,
  }

  export enum ContactDateKind {
    birthday,
    anniversary,
    other,
  }

  export class ContactCardDelayedDataLoader {
    constructor();

    setData(contact: Contact): void;

    close(): void;
  }

  export class ContactManager {
    constructor();

    static showContactCard(contact: Contact, selection: Object): void;
    static showContactCard(contact: Contact, selection: Object, preferredPlacement: Number): void;


    static showDelayLoadedContactCard(contact: Contact, selection: Object, preferredPlacement: Number): ContactCardDelayedDataLoader;


  }

  export class ContactLaunchActionVerbs {
    static call: String;
    static map: String;
    static message: String;
    static post: String;
    static videoCall: String;
    constructor();

  }

  export class IContactField {
    category: ContactFieldCategory;
    name: String;
    type: ContactFieldType;
    value: String;
    constructor();

  }

  export class ContactField {
    category: ContactFieldCategory;
    name: String;
    type: ContactFieldType;
    value: String;
    constructor();
    constructor(value: String, type: ContactFieldType);
    constructor(value: String, type: ContactFieldType, category: ContactFieldCategory);
    constructor(name: String, value: String, type: ContactFieldType, category: ContactFieldCategory);

  }

  export class ContactLocationField {
    city: String;
    country: String;
    postalCode: String;
    region: String;
    street: String;
    unstructuredAddress: String;
    category: ContactFieldCategory;
    name: String;
    type: ContactFieldType;
    value: String;
    constructor();
    constructor(unstructuredAddress: String);
    constructor(unstructuredAddress: String, category: ContactFieldCategory);
    constructor(unstructuredAddress: String, category: ContactFieldCategory, street: String, city: String, region: String, country: String, postalCode: String);

  }

  export class ContactInstantMessageField {
    category: ContactFieldCategory;
    name: String;
    type: ContactFieldType;
    value: String;
    displayText: String;
    launchUri: Object;
    service: String;
    userName: String;
    constructor();
    constructor(userName: String);
    constructor(userName: String, category: ContactFieldCategory);
    constructor(userName: String, category: ContactFieldCategory, service: String, displayText: String, verb: Object);

  }

  export class KnownContactField {
    static email: String;
    static instantMessage: String;
    static location: String;
    static phoneNumber: String;
    constructor();

    static convertNameToType(name: String): ContactFieldType;


    static convertTypeToName(type: ContactFieldType): String;


  }

  export class ContactInformation {
    customFields: Object;
    emails: Object;
    instantMessages: Object;
    locations: Object;
    name: String;
    phoneNumbers: Object;
    constructor();

    getThumbnailAsync(callback: (error: Error, result: Object) => void): void ;

    queryCustomFields(customName: String): Object;

  }

  export class Contact {
    thumbnail: Object;
    name: String;
    fields: Object;
    notes: String;
    id: String;
    addresses: Object;
    connectedServiceAccounts: Object;
    dataSuppliers: Object;
    emails: Object;
    importantDates: Object;
    jobInfo: Object;
    phones: Object;
    providerProperties: Object;
    significantOthers: Object;
    websites: Object;
    honorificNamePrefix: String;
    yomiFamilyName: String;
    middleName: String;
    lastName: String;
    honorificNameSuffix: String;
    yomiGivenName: String;
    firstName: String;
    displayName: String;
    yomiDisplayName: String;
    constructor();

  }

  export class ContactPicker {
    selectionMode: ContactSelectionMode;
    commitButtonText: String;
    desiredFields: Object;
    desiredFieldsWithContactFieldType: Object;
    constructor();

    pickSingleContactAsync(callback: (error: Error, result: ContactInformation) => void): void ;

    pickMultipleContactsAsync(callback: (error: Error, result: Object) => void): void ;

    pickContactAsync(callback: (error: Error, result: Contact) => void): void ;

    pickContactsAsync(callback: (error: Error, result: Object) => void): void ;

  }

  export class IContactFieldFactory {
    constructor();

    createField(value: String, type: ContactFieldType): ContactField;
    createField(value: String, type: ContactFieldType, category: ContactFieldCategory): ContactField;
    createField(name: String, value: String, type: ContactFieldType, category: ContactFieldCategory): ContactField;

  }

  export class IContactLocationFieldFactory {
    constructor();

    createLocation(unstructuredAddress: String): ContactLocationField;
    createLocation(unstructuredAddress: String, category: ContactFieldCategory): ContactLocationField;
    createLocation(unstructuredAddress: String, category: ContactFieldCategory, street: String, city: String, region: String, country: String, postalCode: String): ContactLocationField;

  }

  export class IContactInstantMessageFieldFactory {
    constructor();

    createInstantMessage(userName: String): ContactInstantMessageField;
    createInstantMessage(userName: String, category: ContactFieldCategory): ContactInstantMessageField;
    createInstantMessage(userName: String, category: ContactFieldCategory, service: String, displayText: String, verb: Object): ContactInstantMessageField;

  }

  export class ContactFieldFactory {
    constructor();

    createField(value: String, type: ContactFieldType): ContactField;
    createField(value: String, type: ContactFieldType, category: ContactFieldCategory): ContactField;
    createField(name: String, value: String, type: ContactFieldType, category: ContactFieldCategory): ContactField;

    createLocation(unstructuredAddress: String): ContactLocationField;
    createLocation(unstructuredAddress: String, category: ContactFieldCategory): ContactLocationField;
    createLocation(unstructuredAddress: String, category: ContactFieldCategory, street: String, city: String, region: String, country: String, postalCode: String): ContactLocationField;

    createInstantMessage(userName: String): ContactInstantMessageField;
    createInstantMessage(userName: String, category: ContactFieldCategory): ContactInstantMessageField;
    createInstantMessage(userName: String, category: ContactFieldCategory, service: String, displayText: String, verb: Object): ContactInstantMessageField;

  }

  export class ContactSignificantOther {
    name: String;
    description: String;
    constructor();

  }

  export class ContactWebsite {
    uri: Object;
    description: String;
    constructor();

  }

  export class ContactEmail {
    kind: ContactEmailKind;
    description: String;
    address: String;
    constructor();

  }

  export class ContactPhone {
    number: String;
    kind: ContactPhoneKind;
    description: String;
    constructor();

  }

  export class ContactAddress {
    streetAddress: String;
    region: String;
    postalCode: String;
    locality: String;
    kind: ContactAddressKind;
    description: String;
    country: String;
    constructor();

  }

  export class ContactConnectedServiceAccount {
    serviceName: String;
    id: String;
    constructor();

  }

  export class ContactDate {
    year: Number;
    month: Number;
    kind: ContactDateKind;
    description: String;
    day: Number;
    constructor();

  }

  export class ContactJobInfo {
    title: String;
    office: String;
    manager: String;
    description: String;
    department: String;
    companyYomiName: String;
    companyName: String;
    companyAddress: String;
    constructor();

  }

}



