// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace ApplicationModel { namespace Contacts { 
  v8::Handle<v8::Value> WrapContactCardDelayedDataLoader(::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ UnwrapContactCardDelayedDataLoader(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactManager(::Windows::ApplicationModel::Contacts::ContactManager^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactManager^ UnwrapContactManager(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactLaunchActionVerbs(::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ UnwrapContactLaunchActionVerbs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIContactField(::Windows::ApplicationModel::Contacts::IContactField^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::IContactField^ UnwrapIContactField(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactField(::Windows::ApplicationModel::Contacts::ContactField^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactField^ UnwrapContactField(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactLocationField(::Windows::ApplicationModel::Contacts::ContactLocationField^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactLocationField^ UnwrapContactLocationField(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactInstantMessageField(::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ UnwrapContactInstantMessageField(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapKnownContactField(::Windows::ApplicationModel::Contacts::KnownContactField^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::KnownContactField^ UnwrapKnownContactField(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactInformation(::Windows::ApplicationModel::Contacts::ContactInformation^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactInformation^ UnwrapContactInformation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContact(::Windows::ApplicationModel::Contacts::Contact^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::Contact^ UnwrapContact(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactPicker(::Windows::ApplicationModel::Contacts::ContactPicker^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactPicker^ UnwrapContactPicker(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIContactFieldFactory(::Windows::ApplicationModel::Contacts::IContactFieldFactory^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::IContactFieldFactory^ UnwrapIContactFieldFactory(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIContactLocationFieldFactory(::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ UnwrapIContactLocationFieldFactory(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIContactInstantMessageFieldFactory(::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ UnwrapIContactInstantMessageFieldFactory(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactFieldFactory(::Windows::ApplicationModel::Contacts::ContactFieldFactory^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactFieldFactory^ UnwrapContactFieldFactory(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactSignificantOther(::Windows::ApplicationModel::Contacts::ContactSignificantOther^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ UnwrapContactSignificantOther(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactWebsite(::Windows::ApplicationModel::Contacts::ContactWebsite^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactWebsite^ UnwrapContactWebsite(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactEmail(::Windows::ApplicationModel::Contacts::ContactEmail^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactEmail^ UnwrapContactEmail(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactPhone(::Windows::ApplicationModel::Contacts::ContactPhone^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactPhone^ UnwrapContactPhone(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactAddress(::Windows::ApplicationModel::Contacts::ContactAddress^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactAddress^ UnwrapContactAddress(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactConnectedServiceAccount(::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ UnwrapContactConnectedServiceAccount(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactDate(::Windows::ApplicationModel::Contacts::ContactDate^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactDate^ UnwrapContactDate(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContactJobInfo(::Windows::ApplicationModel::Contacts::ContactJobInfo^ wintRtInstance);
  ::Windows::ApplicationModel::Contacts::ContactJobInfo^ UnwrapContactJobInfo(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitContactFieldTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactFieldType"), enumObject);

    enumObject->Set(String::NewSymbol("email"), Integer::New(0));
    enumObject->Set(String::NewSymbol("phoneNumber"), Integer::New(1));
    enumObject->Set(String::NewSymbol("location"), Integer::New(2));
    enumObject->Set(String::NewSymbol("instantMessage"), Integer::New(3));
    enumObject->Set(String::NewSymbol("custom"), Integer::New(4));
    enumObject->Set(String::NewSymbol("connectedServiceAccount"), Integer::New(5));
    enumObject->Set(String::NewSymbol("importantDate"), Integer::New(6));
    enumObject->Set(String::NewSymbol("address"), Integer::New(7));
    enumObject->Set(String::NewSymbol("significantOther"), Integer::New(8));
    enumObject->Set(String::NewSymbol("notes"), Integer::New(9));
    enumObject->Set(String::NewSymbol("website"), Integer::New(10));
    enumObject->Set(String::NewSymbol("jobInfo"), Integer::New(11));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactFieldCategoryEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactFieldCategory"), enumObject);

    enumObject->Set(String::NewSymbol("none"), Integer::New(0));
    enumObject->Set(String::NewSymbol("home"), Integer::New(1));
    enumObject->Set(String::NewSymbol("work"), Integer::New(2));
    enumObject->Set(String::NewSymbol("mobile"), Integer::New(3));
    enumObject->Set(String::NewSymbol("other"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactSelectionModeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactSelectionMode"), enumObject);

    enumObject->Set(String::NewSymbol("contacts"), Integer::New(0));
    enumObject->Set(String::NewSymbol("fields"), Integer::New(1));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactEmailKindEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactEmailKind"), enumObject);

    enumObject->Set(String::NewSymbol("personal"), Integer::New(0));
    enumObject->Set(String::NewSymbol("work"), Integer::New(1));
    enumObject->Set(String::NewSymbol("other"), Integer::New(2));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactPhoneKindEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactPhoneKind"), enumObject);

    enumObject->Set(String::NewSymbol("home"), Integer::New(0));
    enumObject->Set(String::NewSymbol("mobile"), Integer::New(1));
    enumObject->Set(String::NewSymbol("work"), Integer::New(2));
    enumObject->Set(String::NewSymbol("other"), Integer::New(3));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactAddressKindEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactAddressKind"), enumObject);

    enumObject->Set(String::NewSymbol("home"), Integer::New(0));
    enumObject->Set(String::NewSymbol("work"), Integer::New(1));
    enumObject->Set(String::NewSymbol("other"), Integer::New(2));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitContactDateKindEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ContactDateKind"), enumObject);

    enumObject->Set(String::NewSymbol("birthday"), Integer::New(0));
    enumObject->Set(String::NewSymbol("anniversary"), Integer::New(1));
    enumObject->Set(String::NewSymbol("other"), Integer::New(2));

    return scope.Close(Undefined());
  }



  
  static bool IsRectJsObject(Handle<Value> value)
  {
    if (!value->IsObject())
    {
      return false;
    }

    Handle<String> symbol;
    Handle<Object> obj = value.As<Object>();

    return true;
  }

  ::Windows::Foundation::Rect RectFromJsObject(Handle<Value> value)
  {
    HandleScope scope;
    ::Windows::Foundation::Rect returnValue;
    
    if (!value->IsObject())
    {
      ThrowException(Exception::TypeError(NodeRT::Utils::NewString(L"Unexpected type, expected an object")));
      return returnValue;
    }

    Handle<Object> obj = value.As<Object>();
    Handle<String> symbol;

    return returnValue;
  }

  Handle<Value> RectToJsObject(::Windows::Foundation::Rect value)
  {
    HandleScope scope;

    Handle<Object> obj = Object::New();

    
    return scope.Close(obj);
  }

  
  class ContactCardDelayedDataLoader : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactCardDelayedDataLoader"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setData"), FunctionTemplate::New(SetData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactCardDelayedDataLoader"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactCardDelayedDataLoader(::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactCardDelayedDataLoader *wrapperInstance = new ContactCardDelayedDataLoader(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SetData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactCardDelayedDataLoader *wrapper = ContactCardDelayedDataLoader::Unwrap<ContactCardDelayedDataLoader>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(args[0]))
      {
        try
        {
          ::Windows::ApplicationModel::Contacts::Contact^ arg0 = UnwrapContact(args[0]);
          
          wrapper->_instance->SetData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactCardDelayedDataLoader *wrapper = ContactCardDelayedDataLoader::Unwrap<ContactCardDelayedDataLoader>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          delete wrapper->_instance;
          wrapper->_instance = nullptr;
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }






  private:
    ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactCardDelayedDataLoader(::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ UnwrapContactCardDelayedDataLoader(Handle<Value> value);
    friend bool IsContactCardDelayedDataLoaderWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactCardDelayedDataLoader::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactCardDelayedDataLoader(::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactCardDelayedDataLoader::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ UnwrapContactCardDelayedDataLoader(Handle<Value> value)
  {
     return ContactCardDelayedDataLoader::Unwrap<ContactCardDelayedDataLoader>(value.As<Object>())->_instance;
  }

  void InitContactCardDelayedDataLoader(Handle<Object> exports)
  {
    ContactCardDelayedDataLoader::Init(exports);
  }

  class ContactManager : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactManager"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("showContactCard"), FunctionTemplate::New(ShowContactCard)->GetFunction());
      constructor->Set(String::NewSymbol("showDelayLoadedContactCard"), FunctionTemplate::New(ShowDelayLoadedContactCard)->GetFunction());

      exports->Set(String::NewSymbol("ContactManager"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactManager(::Windows::ApplicationModel::Contacts::ContactManager^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactManager^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactManager^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactManager^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactManager *wrapperInstance = new ContactManager(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  


    static Handle<Value> ShowContactCard(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(args[0])
        && NodeRT::Utils::IsRect(args[1]))
      {
        try
        {
          ::Windows::ApplicationModel::Contacts::Contact^ arg0 = UnwrapContact(args[0]);
          ::Windows::Foundation::Rect arg1 = NodeRT::Utils::RectFromJs(args[1]);
          
          ::Windows::ApplicationModel::Contacts::ContactManager::ShowContactCard(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(args[0])
        && NodeRT::Utils::IsRect(args[1])
        && args[2]->IsInt32())
      {
        try
        {
          ::Windows::ApplicationModel::Contacts::Contact^ arg0 = UnwrapContact(args[0]);
          ::Windows::Foundation::Rect arg1 = NodeRT::Utils::RectFromJs(args[1]);
          ::Windows::UI::Popups::Placement arg2 = static_cast<::Windows::UI::Popups::Placement>(args[2]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactManager::ShowContactCard(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ShowDelayLoadedContactCard(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(args[0])
        && NodeRT::Utils::IsRect(args[1])
        && args[2]->IsInt32())
      {
        try
        {
          ::Windows::ApplicationModel::Contacts::Contact^ arg0 = UnwrapContact(args[0]);
          ::Windows::Foundation::Rect arg1 = NodeRT::Utils::RectFromJs(args[1]);
          ::Windows::UI::Popups::Placement arg2 = static_cast<::Windows::UI::Popups::Placement>(args[2]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactCardDelayedDataLoader^ result;
          result = ::Windows::ApplicationModel::Contacts::ContactManager::ShowDelayLoadedContactCard(arg0, arg1, arg2);
          return scope.Close(WrapContactCardDelayedDataLoader(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



  private:
    ::Windows::ApplicationModel::Contacts::ContactManager^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactManager(::Windows::ApplicationModel::Contacts::ContactManager^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactManager^ UnwrapContactManager(Handle<Value> value);
    friend bool IsContactManagerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactManager::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactManager(::Windows::ApplicationModel::Contacts::ContactManager^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactManager::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactManager^ UnwrapContactManager(Handle<Value> value)
  {
     return ContactManager::Unwrap<ContactManager>(value.As<Object>())->_instance;
  }

  void InitContactManager(Handle<Object> exports)
  {
    ContactManager::Init(exports);
  }

  class ContactLaunchActionVerbs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactLaunchActionVerbs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->SetAccessor(String::NewSymbol("call"), CallGetter);
      constructor->SetAccessor(String::NewSymbol("map"), MapGetter);
      constructor->SetAccessor(String::NewSymbol("message"), MessageGetter);
      constructor->SetAccessor(String::NewSymbol("post"), PostGetter);
      constructor->SetAccessor(String::NewSymbol("videoCall"), VideoCallGetter);

      exports->Set(String::NewSymbol("ContactLaunchActionVerbs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactLaunchActionVerbs(::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactLaunchActionVerbs *wrapperInstance = new ContactLaunchActionVerbs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  




    static Handle<Value> CallGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs::Call;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MapGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs::Map;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs::Message;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PostGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs::Post;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> VideoCallGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs::VideoCall;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    

  private:
    ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactLaunchActionVerbs(::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ UnwrapContactLaunchActionVerbs(Handle<Value> value);
    friend bool IsContactLaunchActionVerbsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactLaunchActionVerbs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactLaunchActionVerbs(::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactLaunchActionVerbs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactLaunchActionVerbs^ UnwrapContactLaunchActionVerbs(Handle<Value> value)
  {
     return ContactLaunchActionVerbs::Unwrap<ContactLaunchActionVerbs>(value.As<Object>())->_instance;
  }

  void InitContactLaunchActionVerbs(Handle<Object> exports)
  {
    ContactLaunchActionVerbs::Init(exports);
  }

  class IContactField : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IContactField"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("category"), CategoryGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("type"), TypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("value"), ValueGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IContactField"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IContactField(::Windows::ApplicationModel::Contacts::IContactField^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::IContactField^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::IContactField^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IContactField *wrapperInstance = new IContactField(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> CategoryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IContactField *wrapper = IContactField::Unwrap<IContactField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldCategory result = wrapper->_instance->Category;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IContactField *wrapper = IContactField::Unwrap<IContactField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IContactField *wrapper = IContactField::Unwrap<IContactField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldType result = wrapper->_instance->Type;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IContactField *wrapper = IContactField::Unwrap<IContactField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Value;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::IContactField^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIContactField(::Windows::ApplicationModel::Contacts::IContactField^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::IContactField^ UnwrapIContactField(Handle<Value> value);
    friend bool IsIContactFieldWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IContactField::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIContactField(::Windows::ApplicationModel::Contacts::IContactField^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IContactField::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::IContactField^ UnwrapIContactField(Handle<Value> value)
  {
     return IContactField::Unwrap<IContactField>(value.As<Object>())->_instance;
  }

  void InitIContactField(Handle<Object> exports)
  {
    IContactField::Init(exports);
  }

  class ContactField : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactField"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("category"), CategoryGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("type"), TypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("value"), ValueGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactField"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactField(::Windows::ApplicationModel::Contacts::ContactField^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactField^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactField^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactField(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[2]->Int32Value());
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactField(arg0,arg1,arg2);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 4
        && args[0]->IsString()
        && args[1]->IsString()
        && args[2]->IsInt32()
        && args[3]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[2]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg3 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[3]->Int32Value());
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactField(arg0,arg1,arg2,arg3);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactField *wrapperInstance = new ContactField(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> CategoryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactField *wrapper = ContactField::Unwrap<ContactField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldCategory result = wrapper->_instance->Category;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactField *wrapper = ContactField::Unwrap<ContactField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactField *wrapper = ContactField::Unwrap<ContactField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldType result = wrapper->_instance->Type;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactField *wrapper = ContactField::Unwrap<ContactField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Value;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactField^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactField(::Windows::ApplicationModel::Contacts::ContactField^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactField^ UnwrapContactField(Handle<Value> value);
    friend bool IsContactFieldWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactField::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactField(::Windows::ApplicationModel::Contacts::ContactField^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactField::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactField^ UnwrapContactField(Handle<Value> value)
  {
     return ContactField::Unwrap<ContactField>(value.As<Object>())->_instance;
  }

  void InitContactField(Handle<Object> exports)
  {
    ContactField::Init(exports);
  }

  class ContactLocationField : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactLocationField"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("city"), CityGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("country"), CountryGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("postalCode"), PostalCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("region"), RegionGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("street"), StreetGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("unstructuredAddress"), UnstructuredAddressGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("category"), CategoryGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("type"), TypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("value"), ValueGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactLocationField"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactLocationField(::Windows::ApplicationModel::Contacts::ContactLocationField^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactLocationField^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactLocationField^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactLocationField(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactLocationField(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 7
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && args[4]->IsString()
        && args[5]->IsString()
        && args[6]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          Platform::String^ arg4 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[4])));
          Platform::String^ arg5 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[5])));
          Platform::String^ arg6 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[6])));
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactLocationField(arg0,arg1,arg2,arg3,arg4,arg5,arg6);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactLocationField *wrapperInstance = new ContactLocationField(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> CityGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->City;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CountryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Country;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PostalCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->PostalCode;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RegionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Region;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StreetGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Street;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> UnstructuredAddressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->UnstructuredAddress;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CategoryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldCategory result = wrapper->_instance->Category;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldType result = wrapper->_instance->Type;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactLocationField *wrapper = ContactLocationField::Unwrap<ContactLocationField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Value;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactLocationField^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactLocationField(::Windows::ApplicationModel::Contacts::ContactLocationField^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactLocationField^ UnwrapContactLocationField(Handle<Value> value);
    friend bool IsContactLocationFieldWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactLocationField::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactLocationField(::Windows::ApplicationModel::Contacts::ContactLocationField^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactLocationField::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactLocationField^ UnwrapContactLocationField(Handle<Value> value)
  {
     return ContactLocationField::Unwrap<ContactLocationField>(value.As<Object>())->_instance;
  }

  void InitContactLocationField(Handle<Object> exports)
  {
    ContactLocationField::Init(exports);
  }

  class ContactInstantMessageField : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactInstantMessageField"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("category"), CategoryGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("type"), TypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("value"), ValueGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("displayText"), DisplayTextGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("launchUri"), LaunchUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("service"), ServiceGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("userName"), UserNameGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactInstantMessageField"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactInstantMessageField(::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactInstantMessageField^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactInstantMessageField(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactInstantMessageField(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 5
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[4]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          ::Windows::Foundation::Uri^ arg4 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[4]));
          
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactInstantMessageField(arg0,arg1,arg2,arg3,arg4);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactInstantMessageField *wrapperInstance = new ContactInstantMessageField(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> CategoryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldCategory result = wrapper->_instance->Category;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactFieldType result = wrapper->_instance->Type;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Value;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DisplayTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->DisplayText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LaunchUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->LaunchUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ServiceGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Service;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> UserNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInstantMessageField *wrapper = ContactInstantMessageField::Unwrap<ContactInstantMessageField>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->UserName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactInstantMessageField(::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ UnwrapContactInstantMessageField(Handle<Value> value);
    friend bool IsContactInstantMessageFieldWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactInstantMessageField::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactInstantMessageField(::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactInstantMessageField::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ UnwrapContactInstantMessageField(Handle<Value> value)
  {
     return ContactInstantMessageField::Unwrap<ContactInstantMessageField>(value.As<Object>())->_instance;
  }

  void InitContactInstantMessageField(Handle<Object> exports)
  {
    ContactInstantMessageField::Init(exports);
  }

  class KnownContactField : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("KnownContactField"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("convertNameToType"), FunctionTemplate::New(ConvertNameToType)->GetFunction());
      constructor->Set(String::NewSymbol("convertTypeToName"), FunctionTemplate::New(ConvertTypeToName)->GetFunction());
      constructor->SetAccessor(String::NewSymbol("email"), EmailGetter);
      constructor->SetAccessor(String::NewSymbol("instantMessage"), InstantMessageGetter);
      constructor->SetAccessor(String::NewSymbol("location"), LocationGetter);
      constructor->SetAccessor(String::NewSymbol("phoneNumber"), PhoneNumberGetter);

      exports->Set(String::NewSymbol("KnownContactField"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    KnownContactField(::Windows::ApplicationModel::Contacts::KnownContactField^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::KnownContactField^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::KnownContactField^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::KnownContactField^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      KnownContactField *wrapperInstance = new KnownContactField(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  


    static Handle<Value> ConvertNameToType(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::ApplicationModel::Contacts::ContactFieldType result;
          result = ::Windows::ApplicationModel::Contacts::KnownContactField::ConvertNameToType(arg0);
          return scope.Close(Integer::New(static_cast<int>(result)));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ConvertTypeToName(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg0 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[0]->Int32Value());
          
          Platform::String^ result;
          result = ::Windows::ApplicationModel::Contacts::KnownContactField::ConvertTypeToName(arg0);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> EmailGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::KnownContactField::Email;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InstantMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::KnownContactField::InstantMessage;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::KnownContactField::Location;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PhoneNumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        Platform::String^ result = ::Windows::ApplicationModel::Contacts::KnownContactField::PhoneNumber;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    

  private:
    ::Windows::ApplicationModel::Contacts::KnownContactField^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapKnownContactField(::Windows::ApplicationModel::Contacts::KnownContactField^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::KnownContactField^ UnwrapKnownContactField(Handle<Value> value);
    friend bool IsKnownContactFieldWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> KnownContactField::s_constructorTemplate;

  v8::Handle<v8::Value> WrapKnownContactField(::Windows::ApplicationModel::Contacts::KnownContactField^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(KnownContactField::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::KnownContactField^ UnwrapKnownContactField(Handle<Value> value)
  {
     return KnownContactField::Unwrap<KnownContactField>(value.As<Object>())->_instance;
  }

  void InitKnownContactField(Handle<Object> exports)
  {
    KnownContactField::Init(exports);
  }

  class ContactInformation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactInformation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("queryCustomFields"), FunctionTemplate::New(QueryCustomFields)->GetFunction());
      
            
      func = FunctionTemplate::New(GetThumbnailAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getThumbnailAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("customFields"), CustomFieldsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("emails"), EmailsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("instantMessages"), InstantMessagesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("locations"), LocationsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("phoneNumbers"), PhoneNumbersGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactInformation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactInformation(::Windows::ApplicationModel::Contacts::ContactInformation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactInformation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactInformation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactInformation *wrapperInstance = new ContactInformation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> GetThumbnailAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Storage::Streams::IRandomAccessStreamWithContentType^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->GetThumbnailAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Storage::Streams::IRandomAccessStreamWithContentType^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage.Streams", "IRandomAccessStreamWithContentType", result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> QueryCustomFields(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactField^>^ result;
          result = wrapper->_instance->QueryCustomFields(arg0);
          return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactField^ val) -> Handle<Value> {
              return WrapContactField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactField^ {
              return UnwrapContactField(value);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CustomFieldsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactField^>^ result = wrapper->_instance->CustomFields;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactField^ val) -> Handle<Value> {
              return WrapContactField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactField^ {
              return UnwrapContactField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> EmailsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactField^>^ result = wrapper->_instance->Emails;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactField^ val) -> Handle<Value> {
              return WrapContactField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactField^ {
              return UnwrapContactField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InstantMessagesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>^ result = wrapper->_instance->InstantMessages;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ val) -> Handle<Value> {
              return WrapContactInstantMessageField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInstantMessageField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ {
              return UnwrapContactInstantMessageField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocationsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactLocationField^>^ result = wrapper->_instance->Locations;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactLocationField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactLocationField^ val) -> Handle<Value> {
              return WrapContactLocationField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactLocationField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactLocationField^ {
              return UnwrapContactLocationField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PhoneNumbersGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactInformation *wrapper = ContactInformation::Unwrap<ContactInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactField^>^ result = wrapper->_instance->PhoneNumbers;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactField^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactField^ val) -> Handle<Value> {
              return WrapContactField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactField^ {
              return UnwrapContactField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactInformation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactInformation(::Windows::ApplicationModel::Contacts::ContactInformation^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactInformation^ UnwrapContactInformation(Handle<Value> value);
    friend bool IsContactInformationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactInformation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactInformation(::Windows::ApplicationModel::Contacts::ContactInformation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactInformation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactInformation^ UnwrapContactInformation(Handle<Value> value)
  {
     return ContactInformation::Unwrap<ContactInformation>(value.As<Object>())->_instance;
  }

  void InitContactInformation(Handle<Object> exports)
  {
    ContactInformation::Init(exports);
  }

  class Contact : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("Contact"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("thumbnail"), ThumbnailGetter, ThumbnailSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter, NameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("fields"), FieldsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("notes"), NotesGetter, NotesSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter, IdSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("addresses"), AddressesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("connectedServiceAccounts"), ConnectedServiceAccountsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("dataSuppliers"), DataSuppliersGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("emails"), EmailsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("importantDates"), ImportantDatesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("jobInfo"), JobInfoGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("phones"), PhonesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("providerProperties"), ProviderPropertiesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("significantOthers"), SignificantOthersGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("websites"), WebsitesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("honorificNamePrefix"), HonorificNamePrefixGetter, HonorificNamePrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yomiFamilyName"), YomiFamilyNameGetter, YomiFamilyNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("middleName"), MiddleNameGetter, MiddleNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastName"), LastNameGetter, LastNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("honorificNameSuffix"), HonorificNameSuffixGetter, HonorificNameSuffixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yomiGivenName"), YomiGivenNameGetter, YomiGivenNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstName"), FirstNameGetter, FirstNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("displayName"), DisplayNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yomiDisplayName"), YomiDisplayNameGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("Contact"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    Contact(::Windows::ApplicationModel::Contacts::Contact^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::Contact^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::Contact^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::Contact();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      Contact *wrapperInstance = new Contact(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ThumbnailGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Storage::Streams::IRandomAccessStreamReference^ result = wrapper->_instance->Thumbnail;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage.Streams", "IRandomAccessStreamReference", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ThumbnailSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::Streams::IRandomAccessStreamReference^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        ::Windows::Storage::Streams::IRandomAccessStreamReference^ winRtValue = dynamic_cast<::Windows::Storage::Streams::IRandomAccessStreamReference^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Thumbnail = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Name = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FieldsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::IContactField^>^ result = wrapper->_instance->Fields;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::IContactField^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::IContactField^ val) -> Handle<Value> {
              return WrapIContactField(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactField^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::IContactField^ {
              return UnwrapIContactField(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NotesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Notes;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NotesSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Notes = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Id;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void IdSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Id = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> AddressesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactAddress^>^ result = wrapper->_instance->Addresses;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactAddress^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactAddress^ val) -> Handle<Value> {
              return WrapContactAddress(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactAddress^ {
              return UnwrapContactAddress(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ConnectedServiceAccountsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>^ result = wrapper->_instance->ConnectedServiceAccounts;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ val) -> Handle<Value> {
              return WrapContactConnectedServiceAccount(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ {
              return UnwrapContactConnectedServiceAccount(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DataSuppliersGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Platform::String^>^ result = wrapper->_instance->DataSuppliers;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Platform::String^>::CreateVectorWrapper(result, 
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            },
            [](Handle<Value> value) -> bool {
              return value->IsString();
            },
            [](Handle<Value> value) -> ::Platform::String^ {
              return ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> EmailsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactEmail^>^ result = wrapper->_instance->Emails;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactEmail^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactEmail^ val) -> Handle<Value> {
              return WrapContactEmail(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactEmail^ {
              return UnwrapContactEmail(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ImportantDatesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactDate^>^ result = wrapper->_instance->ImportantDates;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactDate^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactDate^ val) -> Handle<Value> {
              return WrapContactDate(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactDate^ {
              return UnwrapContactDate(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> JobInfoGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactJobInfo^>^ result = wrapper->_instance->JobInfo;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactJobInfo^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactJobInfo^ val) -> Handle<Value> {
              return WrapContactJobInfo(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactJobInfo^ {
              return UnwrapContactJobInfo(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PhonesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactPhone^>^ result = wrapper->_instance->Phones;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactPhone^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactPhone^ val) -> Handle<Value> {
              return WrapContactPhone(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactPhone^ {
              return UnwrapContactPhone(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ProviderPropertiesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IPropertySet^ result = wrapper->_instance->ProviderProperties;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation.Collections", "IPropertySet", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SignificantOthersGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>^ result = wrapper->_instance->SignificantOthers;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactSignificantOther^ val) -> Handle<Value> {
              return WrapContactSignificantOther(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ {
              return UnwrapContactSignificantOther(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> WebsitesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactWebsite^>^ result = wrapper->_instance->Websites;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactWebsite^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactWebsite^ val) -> Handle<Value> {
              return WrapContactWebsite(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactWebsite^ {
              return UnwrapContactWebsite(value);
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HonorificNamePrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->HonorificNamePrefix;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void HonorificNamePrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->HonorificNamePrefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> YomiFamilyNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->YomiFamilyName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void YomiFamilyNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->YomiFamilyName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MiddleNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->MiddleName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MiddleNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->MiddleName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LastNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->LastName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void LastNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->LastName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> HonorificNameSuffixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->HonorificNameSuffix;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void HonorificNameSuffixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->HonorificNameSuffix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> YomiGivenNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->YomiGivenName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void YomiGivenNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->YomiGivenName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->FirstName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FirstNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return;
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->FirstName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DisplayNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->DisplayName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> YomiDisplayNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Contact *wrapper = Contact::Unwrap<Contact>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->YomiDisplayName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::Contact^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContact(::Windows::ApplicationModel::Contacts::Contact^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::Contact^ UnwrapContact(Handle<Value> value);
    friend bool IsContactWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> Contact::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContact(::Windows::ApplicationModel::Contacts::Contact^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(Contact::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::Contact^ UnwrapContact(Handle<Value> value)
  {
     return Contact::Unwrap<Contact>(value.As<Object>())->_instance;
  }

  void InitContact(Handle<Object> exports)
  {
    Contact::Init(exports);
  }

  class ContactPicker : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactPicker"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
                  
      func = FunctionTemplate::New(PickSingleContactAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("pickSingleContactAsync"), func);
      func = FunctionTemplate::New(PickMultipleContactsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("pickMultipleContactsAsync"), func);
      func = FunctionTemplate::New(PickContactAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("pickContactAsync"), func);
      func = FunctionTemplate::New(PickContactsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("pickContactsAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("selectionMode"), SelectionModeGetter, SelectionModeSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("commitButtonText"), CommitButtonTextGetter, CommitButtonTextSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("desiredFields"), DesiredFieldsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("desiredFieldsWithContactFieldType"), DesiredFieldsWithContactFieldTypeGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactPicker"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactPicker(::Windows::ApplicationModel::Contacts::ContactPicker^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactPicker^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactPicker^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactPicker();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactPicker *wrapperInstance = new ContactPicker(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> PickSingleContactAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::ApplicationModel::Contacts::ContactInformation^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->PickSingleContactAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::ApplicationModel::Contacts::ContactInformation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapContactInformation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> PickMultipleContactsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactInformation^>^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->PickMultipleContactsAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::ApplicationModel::Contacts::ContactInformation^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::ApplicationModel::Contacts::ContactInformation^>::CreateVectorViewWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactInformation^ val) -> Handle<Value> {
              return WrapContactInformation(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactInformation^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactInformation^ {
              return UnwrapContactInformation(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> PickContactAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::ApplicationModel::Contacts::Contact^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->PickContactAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::ApplicationModel::Contacts::Contact^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapContact(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> PickContactsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::Contact^>^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->PickContactsAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::Contact^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::Contact^>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::Contact^ val) -> Handle<Value> {
              return WrapContact(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::Contact^>(value);
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::Contact^ {
              return UnwrapContact(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  



    static Handle<Value> SelectionModeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactSelectionMode result = wrapper->_instance->SelectionMode;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SelectionModeSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return;
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        
        ::Windows::ApplicationModel::Contacts::ContactSelectionMode winRtValue = static_cast<::Windows::ApplicationModel::Contacts::ContactSelectionMode>(value->Int32Value());

        wrapper->_instance->SelectionMode = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CommitButtonTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->CommitButtonText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CommitButtonTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return;
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->CommitButtonText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DesiredFieldsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Platform::String^>^ result = wrapper->_instance->DesiredFields;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Platform::String^>::CreateVectorWrapper(result, 
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            },
            [](Handle<Value> value) -> bool {
              return value->IsString();
            },
            [](Handle<Value> value) -> ::Platform::String^ {
              return ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DesiredFieldsWithContactFieldTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPicker^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPicker *wrapper = ContactPicker::Unwrap<ContactPicker>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::ApplicationModel::Contacts::ContactFieldType>^ result = wrapper->_instance->DesiredFieldsWithContactFieldType;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::ApplicationModel::Contacts::ContactFieldType>::CreateVectorWrapper(result, 
            [](::Windows::ApplicationModel::Contacts::ContactFieldType val) -> Handle<Value> {
              return Integer::New(static_cast<int>(val));
            },
            [](Handle<Value> value) -> bool {
              return value->IsInt32();
            },
            [](Handle<Value> value) -> ::Windows::ApplicationModel::Contacts::ContactFieldType {
              return static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(value->Int32Value());
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactPicker^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactPicker(::Windows::ApplicationModel::Contacts::ContactPicker^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactPicker^ UnwrapContactPicker(Handle<Value> value);
    friend bool IsContactPickerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactPicker::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactPicker(::Windows::ApplicationModel::Contacts::ContactPicker^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactPicker::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactPicker^ UnwrapContactPicker(Handle<Value> value)
  {
     return ContactPicker::Unwrap<ContactPicker>(value.As<Object>())->_instance;
  }

  void InitContactPicker(Handle<Object> exports)
  {
    ContactPicker::Init(exports);
  }

  class IContactFieldFactory : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IContactFieldFactory"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createField"), FunctionTemplate::New(CreateField)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IContactFieldFactory"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IContactFieldFactory(::Windows::ApplicationModel::Contacts::IContactFieldFactory^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::IContactFieldFactory^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactFieldFactory^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::IContactFieldFactory^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IContactFieldFactory *wrapperInstance = new IContactFieldFactory(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> CreateField(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IContactFieldFactory *wrapper = IContactFieldFactory::Unwrap<IContactFieldFactory>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[2]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1, arg2);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 4
        && args[0]->IsString()
        && args[1]->IsString()
        && args[2]->IsInt32()
        && args[3]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[2]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg3 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[3]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1, arg2, arg3);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::ApplicationModel::Contacts::IContactFieldFactory^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIContactFieldFactory(::Windows::ApplicationModel::Contacts::IContactFieldFactory^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::IContactFieldFactory^ UnwrapIContactFieldFactory(Handle<Value> value);
    friend bool IsIContactFieldFactoryWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IContactFieldFactory::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIContactFieldFactory(::Windows::ApplicationModel::Contacts::IContactFieldFactory^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IContactFieldFactory::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::IContactFieldFactory^ UnwrapIContactFieldFactory(Handle<Value> value)
  {
     return IContactFieldFactory::Unwrap<IContactFieldFactory>(value.As<Object>())->_instance;
  }

  void InitIContactFieldFactory(Handle<Object> exports)
  {
    IContactFieldFactory::Init(exports);
  }

  class IContactLocationFieldFactory : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IContactLocationFieldFactory"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createLocation"), FunctionTemplate::New(CreateLocation)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IContactLocationFieldFactory"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IContactLocationFieldFactory(::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IContactLocationFieldFactory *wrapperInstance = new IContactLocationFieldFactory(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> CreateLocation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IContactLocationFieldFactory *wrapper = IContactLocationFieldFactory::Unwrap<IContactLocationFieldFactory>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0, arg1);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 7
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && args[4]->IsString()
        && args[5]->IsString()
        && args[6]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          Platform::String^ arg4 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[4])));
          Platform::String^ arg5 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[5])));
          Platform::String^ arg6 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[6])));
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0, arg1, arg2, arg3, arg4, arg5, arg6);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIContactLocationFieldFactory(::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ UnwrapIContactLocationFieldFactory(Handle<Value> value);
    friend bool IsIContactLocationFieldFactoryWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IContactLocationFieldFactory::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIContactLocationFieldFactory(::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IContactLocationFieldFactory::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::IContactLocationFieldFactory^ UnwrapIContactLocationFieldFactory(Handle<Value> value)
  {
     return IContactLocationFieldFactory::Unwrap<IContactLocationFieldFactory>(value.As<Object>())->_instance;
  }

  void InitIContactLocationFieldFactory(Handle<Object> exports)
  {
    IContactLocationFieldFactory::Init(exports);
  }

  class IContactInstantMessageFieldFactory : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IContactInstantMessageFieldFactory"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createInstantMessage"), FunctionTemplate::New(CreateInstantMessage)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IContactInstantMessageFieldFactory"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IContactInstantMessageFieldFactory(::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IContactInstantMessageFieldFactory *wrapperInstance = new IContactInstantMessageFieldFactory(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> CreateInstantMessage(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IContactInstantMessageFieldFactory *wrapper = IContactInstantMessageFieldFactory::Unwrap<IContactInstantMessageFieldFactory>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0, arg1);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 5
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[4]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          ::Windows::Foundation::Uri^ arg4 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[4]));
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0, arg1, arg2, arg3, arg4);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIContactInstantMessageFieldFactory(::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ UnwrapIContactInstantMessageFieldFactory(Handle<Value> value);
    friend bool IsIContactInstantMessageFieldFactoryWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IContactInstantMessageFieldFactory::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIContactInstantMessageFieldFactory(::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IContactInstantMessageFieldFactory::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::IContactInstantMessageFieldFactory^ UnwrapIContactInstantMessageFieldFactory(Handle<Value> value)
  {
     return IContactInstantMessageFieldFactory::Unwrap<IContactInstantMessageFieldFactory>(value.As<Object>())->_instance;
  }

  void InitIContactInstantMessageFieldFactory(Handle<Object> exports)
  {
    IContactInstantMessageFieldFactory::Init(exports);
  }

  class ContactFieldFactory : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactFieldFactory"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createField"), FunctionTemplate::New(CreateField)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createLocation"), FunctionTemplate::New(CreateLocation)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createInstantMessage"), FunctionTemplate::New(CreateInstantMessage)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactFieldFactory"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactFieldFactory(::Windows::ApplicationModel::Contacts::ContactFieldFactory^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactFieldFactory^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactFieldFactory^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactFieldFactory^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactFieldFactory();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactFieldFactory *wrapperInstance = new ContactFieldFactory(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> CreateField(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactFieldFactory *wrapper = ContactFieldFactory::Unwrap<ContactFieldFactory>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[1]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[2]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1, arg2);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 4
        && args[0]->IsString()
        && args[1]->IsString()
        && args[2]->IsInt32()
        && args[3]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          ::Windows::ApplicationModel::Contacts::ContactFieldType arg2 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldType>(args[2]->Int32Value());
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg3 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[3]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactField^ result;
          result = wrapper->_instance->CreateField(arg0, arg1, arg2, arg3);
          return scope.Close(WrapContactField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateLocation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactFieldFactory *wrapper = ContactFieldFactory::Unwrap<ContactFieldFactory>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0, arg1);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 7
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && args[4]->IsString()
        && args[5]->IsString()
        && args[6]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          Platform::String^ arg4 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[4])));
          Platform::String^ arg5 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[5])));
          Platform::String^ arg6 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[6])));
          
          ::Windows::ApplicationModel::Contacts::ContactLocationField^ result;
          result = wrapper->_instance->CreateLocation(arg0, arg1, arg2, arg3, arg4, arg5, arg6);
          return scope.Close(WrapContactLocationField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateInstantMessage(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactFieldFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ContactFieldFactory *wrapper = ContactFieldFactory::Unwrap<ContactFieldFactory>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsInt32())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0, arg1);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 5
        && args[0]->IsString()
        && args[1]->IsInt32()
        && args[2]->IsString()
        && args[3]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[4]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::ApplicationModel::Contacts::ContactFieldCategory arg1 = static_cast<::Windows::ApplicationModel::Contacts::ContactFieldCategory>(args[1]->Int32Value());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          ::Windows::Foundation::Uri^ arg4 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[4]));
          
          ::Windows::ApplicationModel::Contacts::ContactInstantMessageField^ result;
          result = wrapper->_instance->CreateInstantMessage(arg0, arg1, arg2, arg3, arg4);
          return scope.Close(WrapContactInstantMessageField(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::ApplicationModel::Contacts::ContactFieldFactory^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactFieldFactory(::Windows::ApplicationModel::Contacts::ContactFieldFactory^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactFieldFactory^ UnwrapContactFieldFactory(Handle<Value> value);
    friend bool IsContactFieldFactoryWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactFieldFactory::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactFieldFactory(::Windows::ApplicationModel::Contacts::ContactFieldFactory^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactFieldFactory::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactFieldFactory^ UnwrapContactFieldFactory(Handle<Value> value)
  {
     return ContactFieldFactory::Unwrap<ContactFieldFactory>(value.As<Object>())->_instance;
  }

  void InitContactFieldFactory(Handle<Object> exports)
  {
    ContactFieldFactory::Init(exports);
  }

  class ContactSignificantOther : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactSignificantOther"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter, NameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactSignificantOther"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactSignificantOther(::Windows::ApplicationModel::Contacts::ContactSignificantOther^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactSignificantOther^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactSignificantOther();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactSignificantOther *wrapperInstance = new ContactSignificantOther(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactSignificantOther *wrapper = ContactSignificantOther::Unwrap<ContactSignificantOther>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(info.This()))
      {
        return;
      }

      ContactSignificantOther *wrapper = ContactSignificantOther::Unwrap<ContactSignificantOther>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Name = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactSignificantOther *wrapper = ContactSignificantOther::Unwrap<ContactSignificantOther>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactSignificantOther^>(info.This()))
      {
        return;
      }

      ContactSignificantOther *wrapper = ContactSignificantOther::Unwrap<ContactSignificantOther>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactSignificantOther(::Windows::ApplicationModel::Contacts::ContactSignificantOther^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ UnwrapContactSignificantOther(Handle<Value> value);
    friend bool IsContactSignificantOtherWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactSignificantOther::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactSignificantOther(::Windows::ApplicationModel::Contacts::ContactSignificantOther^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactSignificantOther::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactSignificantOther^ UnwrapContactSignificantOther(Handle<Value> value)
  {
     return ContactSignificantOther::Unwrap<ContactSignificantOther>(value.As<Object>())->_instance;
  }

  void InitContactSignificantOther(Handle<Object> exports)
  {
    ContactSignificantOther::Init(exports);
  }

  class ContactWebsite : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactWebsite"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("uri"), UriGetter, UriSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactWebsite"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactWebsite(::Windows::ApplicationModel::Contacts::ContactWebsite^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactWebsite^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactWebsite^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactWebsite();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactWebsite *wrapperInstance = new ContactWebsite(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> UriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactWebsite *wrapper = ContactWebsite::Unwrap<ContactWebsite>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->Uri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void UriSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(info.This()))
      {
        return;
      }

      ContactWebsite *wrapper = ContactWebsite::Unwrap<ContactWebsite>(info.This());

      try 
      {
        
        ::Windows::Foundation::Uri^ winRtValue = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Uri = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactWebsite *wrapper = ContactWebsite::Unwrap<ContactWebsite>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactWebsite^>(info.This()))
      {
        return;
      }

      ContactWebsite *wrapper = ContactWebsite::Unwrap<ContactWebsite>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactWebsite^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactWebsite(::Windows::ApplicationModel::Contacts::ContactWebsite^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactWebsite^ UnwrapContactWebsite(Handle<Value> value);
    friend bool IsContactWebsiteWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactWebsite::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactWebsite(::Windows::ApplicationModel::Contacts::ContactWebsite^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactWebsite::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactWebsite^ UnwrapContactWebsite(Handle<Value> value)
  {
     return ContactWebsite::Unwrap<ContactWebsite>(value.As<Object>())->_instance;
  }

  void InitContactWebsite(Handle<Object> exports)
  {
    ContactWebsite::Init(exports);
  }

  class ContactEmail : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactEmail"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("kind"), KindGetter, KindSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("address"), AddressGetter, AddressSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactEmail"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactEmail(::Windows::ApplicationModel::Contacts::ContactEmail^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactEmail^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactEmail^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactEmail();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactEmail *wrapperInstance = new ContactEmail(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> KindGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactEmailKind result = wrapper->_instance->Kind;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void KindSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return;
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        
        ::Windows::ApplicationModel::Contacts::ContactEmailKind winRtValue = static_cast<::Windows::ApplicationModel::Contacts::ContactEmailKind>(value->Int32Value());

        wrapper->_instance->Kind = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return;
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> AddressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Address;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void AddressSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactEmail^>(info.This()))
      {
        return;
      }

      ContactEmail *wrapper = ContactEmail::Unwrap<ContactEmail>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Address = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactEmail^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactEmail(::Windows::ApplicationModel::Contacts::ContactEmail^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactEmail^ UnwrapContactEmail(Handle<Value> value);
    friend bool IsContactEmailWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactEmail::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactEmail(::Windows::ApplicationModel::Contacts::ContactEmail^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactEmail::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactEmail^ UnwrapContactEmail(Handle<Value> value)
  {
     return ContactEmail::Unwrap<ContactEmail>(value.As<Object>())->_instance;
  }

  void InitContactEmail(Handle<Object> exports)
  {
    ContactEmail::Init(exports);
  }

  class ContactPhone : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactPhone"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("number"), NumberGetter, NumberSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("kind"), KindGetter, KindSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactPhone"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactPhone(::Windows::ApplicationModel::Contacts::ContactPhone^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactPhone^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactPhone^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactPhone();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactPhone *wrapperInstance = new ContactPhone(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> NumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Number;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NumberSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return;
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Number = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> KindGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactPhoneKind result = wrapper->_instance->Kind;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void KindSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return;
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        
        ::Windows::ApplicationModel::Contacts::ContactPhoneKind winRtValue = static_cast<::Windows::ApplicationModel::Contacts::ContactPhoneKind>(value->Int32Value());

        wrapper->_instance->Kind = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactPhone^>(info.This()))
      {
        return;
      }

      ContactPhone *wrapper = ContactPhone::Unwrap<ContactPhone>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactPhone^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactPhone(::Windows::ApplicationModel::Contacts::ContactPhone^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactPhone^ UnwrapContactPhone(Handle<Value> value);
    friend bool IsContactPhoneWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactPhone::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactPhone(::Windows::ApplicationModel::Contacts::ContactPhone^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactPhone::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactPhone^ UnwrapContactPhone(Handle<Value> value)
  {
     return ContactPhone::Unwrap<ContactPhone>(value.As<Object>())->_instance;
  }

  void InitContactPhone(Handle<Object> exports)
  {
    ContactPhone::Init(exports);
  }

  class ContactAddress : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactAddress"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("streetAddress"), StreetAddressGetter, StreetAddressSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("region"), RegionGetter, RegionSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("postalCode"), PostalCodeGetter, PostalCodeSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("locality"), LocalityGetter, LocalitySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("kind"), KindGetter, KindSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("country"), CountryGetter, CountrySetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactAddress"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactAddress(::Windows::ApplicationModel::Contacts::ContactAddress^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactAddress^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactAddress^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactAddress();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactAddress *wrapperInstance = new ContactAddress(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> StreetAddressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->StreetAddress;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void StreetAddressSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->StreetAddress = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> RegionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Region;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void RegionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Region = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> PostalCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->PostalCode;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PostalCodeSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->PostalCode = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LocalityGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Locality;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void LocalitySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Locality = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> KindGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactAddressKind result = wrapper->_instance->Kind;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void KindSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        ::Windows::ApplicationModel::Contacts::ContactAddressKind winRtValue = static_cast<::Windows::ApplicationModel::Contacts::ContactAddressKind>(value->Int32Value());

        wrapper->_instance->Kind = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CountryGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Country;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CountrySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactAddress^>(info.This()))
      {
        return;
      }

      ContactAddress *wrapper = ContactAddress::Unwrap<ContactAddress>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Country = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactAddress^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactAddress(::Windows::ApplicationModel::Contacts::ContactAddress^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactAddress^ UnwrapContactAddress(Handle<Value> value);
    friend bool IsContactAddressWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactAddress::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactAddress(::Windows::ApplicationModel::Contacts::ContactAddress^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactAddress::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactAddress^ UnwrapContactAddress(Handle<Value> value)
  {
     return ContactAddress::Unwrap<ContactAddress>(value.As<Object>())->_instance;
  }

  void InitContactAddress(Handle<Object> exports)
  {
    ContactAddress::Init(exports);
  }

  class ContactConnectedServiceAccount : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactConnectedServiceAccount"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serviceName"), ServiceNameGetter, ServiceNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter, IdSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactConnectedServiceAccount"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactConnectedServiceAccount(::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactConnectedServiceAccount *wrapperInstance = new ContactConnectedServiceAccount(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ServiceNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactConnectedServiceAccount *wrapper = ContactConnectedServiceAccount::Unwrap<ContactConnectedServiceAccount>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->ServiceName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ServiceNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(info.This()))
      {
        return;
      }

      ContactConnectedServiceAccount *wrapper = ContactConnectedServiceAccount::Unwrap<ContactConnectedServiceAccount>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->ServiceName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactConnectedServiceAccount *wrapper = ContactConnectedServiceAccount::Unwrap<ContactConnectedServiceAccount>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Id;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void IdSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^>(info.This()))
      {
        return;
      }

      ContactConnectedServiceAccount *wrapper = ContactConnectedServiceAccount::Unwrap<ContactConnectedServiceAccount>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Id = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactConnectedServiceAccount(::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ UnwrapContactConnectedServiceAccount(Handle<Value> value);
    friend bool IsContactConnectedServiceAccountWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactConnectedServiceAccount::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactConnectedServiceAccount(::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactConnectedServiceAccount::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactConnectedServiceAccount^ UnwrapContactConnectedServiceAccount(Handle<Value> value)
  {
     return ContactConnectedServiceAccount::Unwrap<ContactConnectedServiceAccount>(value.As<Object>())->_instance;
  }

  void InitContactConnectedServiceAccount(Handle<Object> exports)
  {
    ContactConnectedServiceAccount::Init(exports);
  }

  class ContactDate : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactDate"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("year"), YearGetter, YearSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("month"), MonthGetter, MonthSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("kind"), KindGetter, KindSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("day"), DayGetter, DaySetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactDate"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactDate(::Windows::ApplicationModel::Contacts::ContactDate^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactDate^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactDate^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactDate();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactDate *wrapperInstance = new ContactDate(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> YearGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        ::Platform::IBox<int>^ result = wrapper->_instance->Year;
        return scope.Close(result ? Integer::New(result->Value): static_cast<Handle<Value>>(Undefined()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void YearSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return;
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        
        ::Platform::IBox<int>^ winRtValue = ref new ::Platform::Box<int>(static_cast<int>(value->Int32Value()));

        wrapper->_instance->Year = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MonthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        ::Platform::IBox<unsigned int>^ result = wrapper->_instance->Month;
        return scope.Close(result ? Integer::New(result->Value): static_cast<Handle<Value>>(Undefined()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MonthSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return;
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        
        ::Platform::IBox<unsigned int>^ winRtValue = ref new ::Platform::Box<unsigned int>(static_cast<unsigned int>(value->IntegerValue()));

        wrapper->_instance->Month = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> KindGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        ::Windows::ApplicationModel::Contacts::ContactDateKind result = wrapper->_instance->Kind;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void KindSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return;
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        
        ::Windows::ApplicationModel::Contacts::ContactDateKind winRtValue = static_cast<::Windows::ApplicationModel::Contacts::ContactDateKind>(value->Int32Value());

        wrapper->_instance->Kind = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return;
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DayGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        ::Platform::IBox<unsigned int>^ result = wrapper->_instance->Day;
        return scope.Close(result ? Integer::New(result->Value): static_cast<Handle<Value>>(Undefined()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DaySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactDate^>(info.This()))
      {
        return;
      }

      ContactDate *wrapper = ContactDate::Unwrap<ContactDate>(info.This());

      try 
      {
        
        ::Platform::IBox<unsigned int>^ winRtValue = ref new ::Platform::Box<unsigned int>(static_cast<unsigned int>(value->IntegerValue()));

        wrapper->_instance->Day = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactDate^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactDate(::Windows::ApplicationModel::Contacts::ContactDate^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactDate^ UnwrapContactDate(Handle<Value> value);
    friend bool IsContactDateWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactDate::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactDate(::Windows::ApplicationModel::Contacts::ContactDate^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactDate::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactDate^ UnwrapContactDate(Handle<Value> value)
  {
     return ContactDate::Unwrap<ContactDate>(value.As<Object>())->_instance;
  }

  void InitContactDate(Handle<Object> exports)
  {
    ContactDate::Init(exports);
  }

  class ContactJobInfo : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContactJobInfo"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("title"), TitleGetter, TitleSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("office"), OfficeGetter, OfficeSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("manager"), ManagerGetter, ManagerSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("description"), DescriptionGetter, DescriptionSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("department"), DepartmentGetter, DepartmentSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("companyYomiName"), CompanyYomiNameGetter, CompanyYomiNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("companyName"), CompanyNameGetter, CompanyNameSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("companyAddress"), CompanyAddressGetter, CompanyAddressSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ContactJobInfo"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContactJobInfo(::Windows::ApplicationModel::Contacts::ContactJobInfo^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::ApplicationModel::Contacts::ContactJobInfo^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::ApplicationModel::Contacts::ContactJobInfo^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::ApplicationModel::Contacts::ContactJobInfo();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContactJobInfo *wrapperInstance = new ContactJobInfo(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> TitleGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Title;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void TitleSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Title = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> OfficeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Office;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void OfficeSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Office = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ManagerGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Manager;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ManagerSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Manager = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DescriptionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Description;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DescriptionSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Description = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DepartmentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Department;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DepartmentSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Department = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CompanyYomiNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->CompanyYomiName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompanyYomiNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->CompanyYomiName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CompanyNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->CompanyName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompanyNameSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->CompanyName = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CompanyAddressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->CompanyAddress;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompanyAddressSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::ApplicationModel::Contacts::ContactJobInfo^>(info.This()))
      {
        return;
      }

      ContactJobInfo *wrapper = ContactJobInfo::Unwrap<ContactJobInfo>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->CompanyAddress = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::ApplicationModel::Contacts::ContactJobInfo^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContactJobInfo(::Windows::ApplicationModel::Contacts::ContactJobInfo^ wintRtInstance);
    friend ::Windows::ApplicationModel::Contacts::ContactJobInfo^ UnwrapContactJobInfo(Handle<Value> value);
    friend bool IsContactJobInfoWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContactJobInfo::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContactJobInfo(::Windows::ApplicationModel::Contacts::ContactJobInfo^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContactJobInfo::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::ApplicationModel::Contacts::ContactJobInfo^ UnwrapContactJobInfo(Handle<Value> value)
  {
     return ContactJobInfo::Unwrap<ContactJobInfo>(value.As<Object>())->_instance;
  }

  void InitContactJobInfo(Handle<Object> exports)
  {
    ContactJobInfo::Init(exports);
  }

} } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::ApplicationModel::Contacts::InitContactFieldTypeEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactFieldCategoryEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactSelectionModeEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactEmailKindEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactPhoneKindEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactAddressKindEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactDateKindEnum(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactCardDelayedDataLoader(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactManager(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactLaunchActionVerbs(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitIContactField(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactField(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactLocationField(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactInstantMessageField(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitKnownContactField(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactInformation(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContact(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactPicker(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitIContactFieldFactory(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitIContactLocationFieldFactory(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitIContactInstantMessageFieldFactory(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactFieldFactory(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactSignificantOther(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactWebsite(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactEmail(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactPhone(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactAddress(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactConnectedServiceAccount(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactDate(exports);
  NodeRT::Windows::ApplicationModel::Contacts::InitContactJobInfo(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.ApplicationModel.Contacts", exports);
}


NODE_MODULE(binding, init)